==> react-text-animate-1.0.0.tgz: package/README.md <==
<p align="center">
  <h1 align="center">✨ React Text Animate ✨</h1>
</p>

<p align="center">
  <em>
    Elevate your React projects with a stunning collection of sleek, modern, and silky-smooth text animation components powered by Framer Motion. Effortlessly add a touch of elegance and bring your UI to life, adding dynamic flair and visual appeal that will leave your users impressed!
  </em>
</p>

<p align="center">
  <!-- NPM package version -->
  <a href="https://www.npmjs.com/package/react-text-animate" target="_blank" rel="noopener noreferrer">
	  <img src="https://img.shields.io/npm/v/react-text-animate?logo=npm&color=cb3837&style=for-the-badge" alt="license">
  </a>

  <!-- Minified Bundle Size -->
  <img src="https://img.shields.io/bundlephobia/min/react-text-animate?style=for-the-badge&color=yellow" alt="Minified Size">

  <!-- Latest GitHub Release-->
  <a href="https://github.com/mwaqar29/react-text-animate/releases" target="_blank" rel="noopener noreferrer">
    <img alt="GitHub Release" src="https://img.shields.io/github/v/release/mwaqar29/react-text-animate?style=for-the-badge&logo=github&label=Release&color=plum">
  </a>

  <!-- Last Commit -->
  <img src="https://img.shields.io/github/last-commit/mwaqar29/react-text-animate?logo=git&logoColor=white&style=for-the-badge" alt="last-commit">

  <!-- Repo Top Language-->
  <img src="https://img.shields.io/github/languages/top/mwaqar29/react-text-animate?style=for-the-badge" alt="repo-top-language">

  <!-- License-->
  <a href="#-license" target="_blank" rel="noopener noreferrer">
  <img src="https://img.shields.io/github/license/mwaqar29/react-text-animate?logo=opensourceinitiative&logoColor=white&style=for-the-badge" alt="license">
  </a>

  <!-- Code of Conduct-->
  <a href="https://github.com/mwaqar29/react-text-animate/blob/main/CODE_OF_CONDUCT.md" target="_blank" rel="noopener noreferrer">
    <img src="https://img.shields.io/badge/code_of-conduct-hotpink?style=for-the-badge" alt="code-of-conduct">
  </a>

  <!-- Contributions Welcome-->
  <a href="#-contributing" target="_blank" rel="noopener noreferrer">
    <img src="https://img.shields.io/badge/contributions-welcome-8A2BE2?style=for-the-badge" alt="contributions-welcome">
  </a>

  <!-- Commitzen Friendly-->
  <a href="http://commitizen.github.io/cz-cli/" target="_blank" rel="noopener noreferrer">
    <img src="https://img.shields.io/badge/commitizen-friendly-brightgreen.svg?style=for-the-badge" alt="Commitizen friendly" />
  </a>
<p>

<p align="center">
<em>Built with 🛠️</em>
</p>

<p align="center">
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/react/react-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/typescript/typescript-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/rollup/rollup-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/framermotion/framermotion-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/eslint/eslint-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/html5/html5-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/css3/css3-original.svg" height="42" width="42" />
</p>

<hr/>

## 🗂️ Table of Contents

- [📍 Overview](#-overview)
- [🎁 Features](#-features)
- [📂 Repository Structure](#-repository-structure)
- [🚀 Quick Start](#-quick-start)
  - [⚙️ Installation](#️-installation)
  - [💻 Usage](#-usage)
- [🧭 Project Roadmap](#-project-roadmap)
- [🤝 Contributing](#-contributing)
- [📒 Changelog](#-changelog)
- [📄 License](#-license)
- [👊 Acknowledgments](#-acknowledgments)

## 📍 Overview

The `react-text-animate` library offers a seamless blend of ease & functionality, providing declarative, plug-and-play animated text components alongside a range of customization options. Built entirely with TypeScript and powered by Framer Motion, the library delivers production-ready animations with buttery-smooth performance at 60fps. The animated text components also feature built-in viewport detection that activates animations as the component scrolls into view, while also offering customization options to enhance their versatility. With robust code quality maintained by ESLint and Prettier, and an optimized, compact bundle size achieved through Rollup's tree shaking and dead code elimination, this library is both efficient and reliable.

## 🎁 Features

- 🧩 **Simple and Declarative**: Plug-and-play components that are easy to use yet customizable.
- 🔭 **Built-in Viewport Detection**: Activates animations as the component scrolls into view.
- 📘 **TypeScript-Powered:** Components are built purely with TypeScript for type safety and reliability.
- 🌀 **Fueled by Framer Motion**: Production-ready, 60fps animations that are smooth and performant.
- ✅ **High-Quality Code**: ESLint and Prettier integration ensures clean, robust code.
- ⚡ **Optimized Bundle Size**: Rollup's tree shaking and dead code elimination keep the bundle lightweight and efficient.

## 📂 Repository Structure

```sh
└── react-text-animate/
    ├── .husky/
    ├── src/
    │   ├── assets/
    │   ├── components/
    │   │   ├── text-effect-3/
    │   │   │   ├── index.tsx
    │   │   │   └── index.css
    │   │   └── ...
    │   ├── index.ts
    │   └── styles.css
    ├── CODE_OF_CONDUCT.md
    ├── CONTRIBUTING.md
    ├── LICENSE
    ├── README.md
    ├── package.json
    ├── rollup.config.ts
    └── ...
```

## 🚀 Quick Start

**_Requirements:_**

A React application.

> [!NOTE]
> This package is built using `React v18.3`. So try to have something similar in your project so that the library works without any issues.

### ⚙️ Installation

Install the `react-text-animate` library in your react application using one of the the below commands (as per the package manager installed in your system).

- npm
  ```sh
  npm i react-text-animate
  ```
- yarn
  ```sh
  yarn add react-text-animate
  ```
- pnpm
  ```sh
  pnpm add react-text-animate
  ```

### 💻 Usage

Out of the box, you can use one of the components as shown in the example below:

```jsx
import { TextEffectOne } from 'react-text-animate'

const App = () => {
  const words = 'TYPOGRAPHY'
  return <TextEffectOne text={words} />
}

export default App
```

And here is the result! 🎉

![Text Effect One Result](https://github.com/mwaqar29/react-text-animate/blob/main/src/assets/images/example/text-effect-1-result.gif)

Yes, it is as simple as that to get started! But don't get carried away by the simplicity. Every component offers a variety of customization props. Feel free to experiment with these settings until you achieve your desired result. Below are the ones available for the `<TextEffectOne />` component mentioned above:

> [!NOTE]
> Most of the props for the `<TextEffectOne />` component are common to all other animated text components. Only the **additional** props for other components will be listed to avoid redundancy. So a component (except `<TextEffectOne />`) may have more props than those listed in the table below.

#### Component: `<TextEffectOne />`

| Prop                      | Type                        | Default                                                | Description                                                                                                                                                                                |
| ------------------------- | --------------------------- | ------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| `wrapperElement`          | keyof JSX.IntrinsicElements | `p`                                                    | JSX-equivalent of HTML Element wrapping the entire component<br/>For e.g. `div`, `span`, `strong` etc.                                                                                     |
| `text`                    | string \| string[]          | `null`                                                 | The actual text to animate. For e.g `"Hey yo!"`, `["Multline", "Line 2"]`.                                                                                                                 |
| `className`               | string                      | `null`                                                 | HTML class name applied to the wrapper element to style the text. **Tip**: Use `tailwind` utility classes for styling!                                                                     |
| `style`                   | CSSProperties               | `null`                                                 | JSX inline style object. For e.g `{ fontStyle: 'italic' }`.                                                                                                                                |
| `rotation`                | number                      | `0`                                                    | Rotation Angle of letters. For e.g. `67.5`, `-45` (in degree).                                                                                                                             |
| `staggerDuration`         | number                      | `0.1`                                                  | Delay between the animation of each individual letter (in seconds).                                                                                                                        |
| `fromTop`                 | boolean                     | `false`                                                | Animate letters from top to bottom.                                                                                                                                                        |
| `fromLast`                | boolean                     | `false`                                                | Animate letters from right to left.                                                                                                                                                        |
| `initialDelay`            | number                      | `0`                                                    | Delay before starting the animation (in seconds).                                                                                                                                          |
| `animateOnce`             | boolean                     | `false`                                                | When the text component scrolls out of view and then back into view, the animation is triggered again. This prop can be used to turn this behaviour off.                                   |
| `elementVisibilityAmount` | number                      | `0.5`                                                  | The amount of an element that needs to enter the viewport for the animation to be triggered. This is defined as a number between 0 and 1.                                                  |
| `lineHeight`              | number                      | `0.8` for text with only uppercase letters, else `1.2` | Specifies the line height to prevent lowercase characters with descenders (like 'g', 'j', 'p', 'q', 'y') from being cut off in some fonts. Adjust this property to fit the font as needed. |

#### Component: `<TextEffectTwo />`

| Prop                | Type    | Default | Description                                               |
| ------------------- | ------- | ------- | --------------------------------------------------------- |
| `words`             | string  | `null`  | The actual text to animate. For e.g `"Hey yo!"`.          |
| `filter`            | boolean | `false` | Toggle blur effect in animation.                          |
| `animationDuration` | number  | `0.1`   | TIme taken for entire animation to complete (in seconds). |

#### Component: `<TextEffectThree />`

The props for this component include some from both `<TextEffectOne />` and `<TextEffectTwo />`.<br/>
_**Note**: This component animates on hover!_

## 🧭 Project Roadmap

We'll keep adding more animated text components in future! <br/>
Additionally, if you want to contribute any, do check out the [Contributing](#-contributing) section.

## 📒 Changelog

Please read [CHANGELOG.md](https://github.com/mwaqar29/react-text-animate/blob/main/CHANGELOG.md).

## 🤝 Contributing

> [!IMPORTANT]
> Please read [CONTRIBUTING.md](https://github.com/mwaqar29/react-text-animate/blob/main/CONTRIBUTING.md) & [CODE_OF_CONDUCT.md](https://github.com/mwaqar29/react-text-animate/blob/main/CODE_OF_CONDUCT.md) for details on our code of conduct, and the process for submitting pull requests to us.
> I also strongly recommend that you check if you are using the latest version of the project. If you are not up-to-date, see if updating fixes your issue first. Also, check for open issues and pull requests to see if someone else is working on something similar.

Contributions are welcome! Here are several ways you can contribute:

- **[Report Issues](https://github.com/mwaqar29/react-text-animate/issues)**: Submit bugs found or log feature requests for the `react-text-animate` project.
- **[Submit Pull Requests](https://github.com/mwaqar29/react-text-animate/blob/main/CONTRIBUTING.md)**: Review open PRs and contribute by submitting your own new animated text component PRs.

<br/>
<h6 align="center">Thanks 👊 to all contributors!</h6>
<p align="center">
   <a href="https://github.com/mwaqar29/react-text-animate/graphs/contributors">
      <img src="https://contrib.rocks/image?repo=mwaqar29/react-text-animate">
   </a>
</p>

## 📄 License

This project is protected under the [MIT](https://choosealicense.com/licenses/mit/) License. For more details, refer to the [LICENSE](https://github.com/mwaqar29/react-text-animate/blob/main/LICENSE) file.

## 👊 Acknowledgments

Some of these animations are inspired by the work of brilliant and generous individuals. I want to extend my heartfelt thanks to them for their invaluable contributions to the community.

- [Tom Is Loading, Hover Dev LLC](https://github.com/TomIsLoading)
- [Manu Arora, Aceternity UI](https://github.com/manuarora700)

[**Return to 'Overview' ⬆️**](#-overview)

<p align="center">
  Thanks for reading!<br/>
  <em>Love this project ? Don't forget to</em> ⭐ <em>me!</em>
</p>

<p align="center">
  <img src="https://img.shields.io/badge/MADE_WITH-%E2%9D%A4-D0021B?style=for-the-badge&labelColor=D22238" alt="Made with ❤">
</p>

==> react-text-animate-2.0.0.tgz: package/README.md <==
<p align="center">
  <h1 align="center">✨ React Text Animate ✨</h1>
</p>

<p align="center">
  <em>
    Elevate your React/Next.js projects with a stunning collection of sleek, modern, and silky-smooth text animation components powered by Framer Motion. Effortlessly add a touch of elegance and bring your UI to life, adding dynamic flair and visual appeal that will leave your users impressed!
  </em>
</p>

<p align="center">
  <!-- NPM package version -->
  <a href="https://www.npmjs.com/package/react-text-animate" target="_blank" rel="noopener noreferrer">
	  <img src="https://img.shields.io/npm/v/react-text-animate?logo=npm&color=cb3837&style=for-the-badge" alt="license">
  </a>

  <!-- Minified Bundle Size -->
  <img src="https://img.shields.io/bundlephobia/min/react-text-animate?style=for-the-badge&color=yellow" alt="Minified Size">

  <!-- Latest GitHub Release-->
  <a href="https://github.com/mwaqar29/react-text-animate/releases" target="_blank" rel="noopener noreferrer">
    <img alt="GitHub Release" src="https://img.shields.io/github/v/release/mwaqar29/react-text-animate?style=for-the-badge&logo=github&label=Release&color=plum">
  </a>

  <!-- Last Commit -->
  <img src="https://img.shields.io/github/last-commit/mwaqar29/react-text-animate?logo=git&logoColor=white&style=for-the-badge" alt="last-commit">

  <!-- Repo Top Language-->
  <img src="https://img.shields.io/github/languages/top/mwaqar29/react-text-animate?style=for-the-badge" alt="repo-top-language">

  <!-- License-->
  <a href="#-license" target="_blank" rel="noopener noreferrer">
  <img src="https://img.shields.io/github/license/mwaqar29/react-text-animate?logo=opensourceinitiative&logoColor=white&style=for-the-badge" alt="license">
  </a>

  <!-- Code of Conduct-->
  <a href="https://github.com/mwaqar29/react-text-animate/blob/main/CODE_OF_CONDUCT.md" target="_blank" rel="noopener noreferrer">
    <img src="https://img.shields.io/badge/code_of-conduct-hotpink?style=for-the-badge" alt="code-of-conduct">
  </a>

  <!-- Contributions Welcome-->
  <a href="#-contributing" target="_blank" rel="noopener noreferrer">
    <img src="https://img.shields.io/badge/contributions-welcome-8A2BE2?style=for-the-badge" alt="contributions-welcome">
  </a>

  <!-- Commitzen Friendly-->
  <a href="http://commitizen.github.io/cz-cli/" target="_blank" rel="noopener noreferrer">
    <img src="https://img.shields.io/badge/commitizen-friendly-brightgreen.svg?style=for-the-badge" alt="Commitizen friendly" />
  </a>
<p>

<p align="center">
<em>Built with 🛠️</em>
</p>

<p align="center">
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/react/react-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/typescript/typescript-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/rollup/rollup-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/framermotion/framermotion-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/eslint/eslint-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/html5/html5-original.svg" height="42" width="42" />
  <img src="https://cdn.jsdelivr.net/gh/devicons/devicon@latest/icons/css3/css3-original.svg" height="42" width="42" />
</p>

<hr/>

## 🗂️ Table of Contents

- [📍 Overview](#-overview)
- [🎁 Features](#-features)
- [📂 Repository Structure](#-repository-structure)
- [🚀 Quick Start](#-quick-start)
  - [⚙️ Installation](#️-installation)
  - [💻 Usage](#-usage)
- [🧭 Project Roadmap](#-project-roadmap)
- [🤝 Contributing](#-contributing)
- [📒 Changelog](#-changelog)
- [📄 License](#-license)
- [👊 Acknowledgments](#-acknowledgments)

## 📍 Overview

The `react-text-animate` library offers a seamless blend of ease & functionality, providing declarative, plug-and-play animated text components alongside a range of customization options. Built entirely with TypeScript and powered by Framer Motion, the library delivers production-ready animations with buttery-smooth performance at 60fps. The animated text components also feature built-in viewport detection that activates animations as the component scrolls into view, while also offering customization options to enhance their versatility. With robust code quality maintained by ESLint and Prettier, and an optimized, compact bundle size achieved through Rollup's tree shaking and dead code elimination, this library is both efficient and reliable.

## 🎁 Features

- 🧩 **Simple and Declarative**: Plug-and-play components that are easy to use yet customizable.
- 🔭 **Built-in Viewport Detection**: Activates animations as the component scrolls into view.
- 📘 **TypeScript-Powered:** Components are built purely with TypeScript for type safety and reliability.
- 🌀 **Fueled by Framer Motion**: Production-ready, 60fps animations that are smooth and performant.
- ✅ **High-Quality Code**: ESLint and Prettier integration ensures clean, robust code.
- ⚡ **Optimized Bundle Size**: Rollup's tree shaking and dead code elimination keep the bundle lightweight and efficient.

## 📂 Repository Structure

```sh
└── react-text-animate/
    ├── .husky/
    ├── src/
    │   ├── assets/
    │   ├── components/
    │   │   ├── text-effect-3/
    │   │   │   ├── index.tsx
    │   │   │   └── index.css
    │   │   └── ...
    │   ├── index.ts
    │   └── styles.css
    ├── package.json
    ├── rollup.config.ts
    └── ...
```

## 🚀 Quick Start

**_Requirements:_**

A React/Next.js application.

> [!NOTE]
> This package is built using `React v18.3`. So try to have something similar in your project so that the library works without any issues.

### ⚙️ Installation

Install the `react-text-animate` library in your React/Next.js application using one of the the below commands (as per the package manager installed in your system).

- npm
  ```sh
  npm i react-text-animate
  ```
- yarn
  ```sh
  yarn add react-text-animate
  ```
- pnpm
  ```sh
  pnpm add react-text-animate
  ```

### 💻 Usage

Out of the box, you can use one of the components as shown in the example below:

```jsx
import { TextEffectOne } from 'react-text-animate'

const App = () => {
  const words = 'TYPOGRAPHY'
  return <TextEffectOne text={words} />
}

export default App
```

And here is the result! 🎉

![Text Effect One Result](https://github.com/mwaqar29/react-text-animate/blob/main/src/assets/images/example/text-effect-1-result.gif)

Yes, it is as simple as that to get started! But don't get carried away by the simplicity. Every component offers a variety of customization props. Feel free to experiment with these settings until you achieve your desired result. Below are the ones available for the `<TextEffectOne />` component mentioned above:

> [!NOTE]
> Most of the props for the `<TextEffectOne />` component are common to all other animated text components. Only the **additional** props for other components will be listed to avoid redundancy. So a component (except `<TextEffectOne />`) may have more props than those listed in the table below.

#### Component: `<TextEffectOne />`

| Prop                      | Type                        | Default                                                | Description                                                                                                                                                                                |
| ------------------------- | --------------------------- | ------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| `wrapperElement`          | keyof JSX.IntrinsicElements | `p`                                                    | JSX-equivalent of HTML Element wrapping the entire component<br/>For e.g. `div`, `span`, `strong` etc.                                                                                     |
| `text`                    | string \| string[]          | `null`                                                 | The actual text to animate. For e.g `"Hey yo!"`, `["Multline", "Line 2"]`.                                                                                                                 |
| `className`               | string                      | `null`                                                 | HTML class name applied to the wrapper element to style the text. **Tip**: Use `tailwind` utility classes for styling!                                                                     |
| `style`                   | CSSProperties               | `null`                                                 | JSX inline style object. For e.g `{ fontStyle: 'italic' }`.                                                                                                                                |
| `rotation`                | number                      | `0`                                                    | Rotation Angle of letters. For e.g. `67.5`, `-45` (in degree).                                                                                                                             |
| `staggerDuration`         | number                      | `0.1`                                                  | Delay between the animation of each individual letter (in seconds).                                                                                                                        |
| `fromTop`                 | boolean                     | `false`                                                | Animate letters from top to bottom.                                                                                                                                                        |
| `fromLast`                | boolean                     | `false`                                                | Animate letters from right to left.                                                                                                                                                        |
| `initialDelay`            | number                      | `0`                                                    | Delay before starting the animation (in seconds).                                                                                                                                          |
| `animateOnce`             | boolean                     | `false`                                                | When the text component scrolls out of view and then back into view, the animation is triggered again. This prop can be used to turn this behaviour off.                                   |
| `elementVisibilityAmount` | number                      | `0.5`                                                  | The amount of an element that needs to enter the viewport for the animation to be triggered. This is defined as a number between 0 and 1.                                                  |
| `lineHeight`              | number                      | `0.8` for text with only uppercase letters, else `1.2` | Specifies the line height to prevent lowercase characters with descenders (like 'g', 'j', 'p', 'q', 'y') from being cut off in some fonts. Adjust this property to fit the font as needed. |

#### Component: `<TextEffectTwo />`

| Prop                | Type    | Default | Description                                               |
| ------------------- | ------- | ------- | --------------------------------------------------------- |
| `text`              | string  | `null`  | The actual text to animate. For e.g `"Hey yo!"`.          |
| `filter`            | boolean | `true`  | Toggle blur effect in animation.                          |
| `animationDuration` | number  | `0.1`   | TIme taken for entire animation to complete (in seconds). |

#### Component: `<TextEffectThree />`

The props for this component include some from both `<TextEffectOne />` and `<TextEffectTwo />`.<br/>
_**Note**: This component animates on hover!_

## 🧭 Project Roadmap

We'll keep adding more animated text components in future! <br/>
Additionally, if you want to contribute any, do check out the [Contributing](#-contributing) section.

## 📒 Changelog

Please read [CHANGELOG.md](https://github.com/mwaqar29/react-text-animate/blob/main/CHANGELOG.md).

## 🤝 Contributing

> [!IMPORTANT]
> Please read [CONTRIBUTING.md](https://github.com/mwaqar29/react-text-animate/blob/main/CONTRIBUTING.md) & [CODE_OF_CONDUCT.md](https://github.com/mwaqar29/react-text-animate/blob/main/CODE_OF_CONDUCT.md) for details on our code of conduct, and the process for submitting pull requests to us.
> I also strongly recommend that you check if you are using the latest version of the project. If you are not up-to-date, see if updating fixes your issue first. Also, check for open issues and pull requests to see if someone else is working on something similar.

Contributions are welcome! Here are several ways you can contribute:

- **[Report Issues](https://github.com/mwaqar29/react-text-animate/issues)**: Submit bugs found or log feature requests for the `react-text-animate` project.
- **[Submit Pull Requests](https://github.com/mwaqar29/react-text-animate/blob/main/CONTRIBUTING.md)**: Review open PRs and contribute by submitting your own new animated text component PRs.

<br/>
<h6 align="center">Thanks 👊 to all contributors!</h6>
<p align="center">
   <a href="https://github.com/mwaqar29/react-text-animate/graphs/contributors">
      <img src="https://contrib.rocks/image?repo=mwaqar29/react-text-animate">
   </a>
</p>

## 📄 License

This project is protected under the [MIT](https://choosealicense.com/licenses/mit/) License. For more details, refer to the [LICENSE](https://github.com/mwaqar29/react-text-animate/blob/main/LICENSE) file.

## 👊 Acknowledgments

Some of these animations are inspired by the work of brilliant and generous individuals. I want to extend my heartfelt thanks to them for their invaluable contributions to the community.

- [Tom Is Loading, Hover Dev LLC](https://github.com/TomIsLoading)
- [Manu Arora, Aceternity UI](https://github.com/manuarora700)

[**Return to 'Overview' ⬆️**](#-overview)

<p align="center">
  Thanks for reading!<br/>
  <em>Love this project ? Don't forget to</em> ⭐ <em>me!</em>
</p>

<p align="center">
  <img src="https://img.shields.io/badge/MADE_WITH-%E2%9D%A4-D0021B?style=for-the-badge&labelColor=D22238" alt="Made with ❤">
</p>
